<?php

namespace _PhpScoperAtome\Atome;

use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Services\Validator;
use WC_Payment_Gateway;
/** @internal */
class AtomeGateway extends WC_Payment_Gateway
{
    use CreateOrderBeforePayment;
    use View;
    use Setting;
    use Query;
    private static $instance = null;
    /**
     * @var Validator
     */
    protected $validator;
    public function __construct()
    {
        $this->id = Atome::ID;
        $this->icon = Atome::icon();
        $this->has_fields = Atome::HAS_FIELDS;
        $this->method_title = Atome::TITLE;
        $this->title = Atome::TITLE;
        $this->method_description = Atome::DESCRIPTION . ' (version ' . Atome::version() . ')';
        $this->supports = Atome::SUPPORTS;
        $this->description = $this->get_description();
        $this->init_form_fields();
        $this->init_settings();
        $this->validator = new Validator();
    }
    public static function instance()
    {
        if (\is_null(self::$instance)) {
            self::$instance = new self();
        }
        return self::$instance;
    }
    public function availablePaymentGateways($gateways)
    {
        if (is_admin()) {
            return $gateways;
        }
        if (!$this->validator->isSupportedCurrency()) {
            unset($gateways[$this->id]);
        }
        if (!$this->validator->inValidSpendAmountRange($this->get_order_total())) {
            unset($gateways[$this->id]);
        }
        return $gateways;
    }
    public function can_refund_order($order)
    {
        return $order->get_payment_method() === $this->id && $this->supports('refunds') && $order->get_remaining_refund_amount() != 0.0;
    }
    public function process_refund($order_id, $amount = null, $reason = '')
    {
        $refund = new \_PhpScoperAtome\Atome\Payment\Refund();
        return $refund->setOrderId($order_id)->setAmount($amount)->handle();
    }
    public function payment_fields()
    {
        echo wpautop(wptexturize($this->description));
    }
}
