<?php

namespace _PhpScoperAtome\Atome\Config;

use _PhpScoperAtome\Atome\AtomeSettingApi;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Services\Logger;
/** @internal */
class Config
{
    /**
     * @var Config
     */
    private static $instance;
    protected $configs = [];
    protected $options = [];
    protected $localeConfig = [];
    /**
     * @var AtomeSettingApi
     */
    protected $atomeSettingApi;
    /**
     * @var Logger
     */
    protected $logger;
    public function boot()
    {
        $this->atomeSettingApi = new AtomeSettingApi();
        $this->logger = new Logger();
        $this->setLocaleConfig();
        $this->syncConfigIfExpired();
    }
    public static function instance()
    {
        if (\is_null(self::$instance)) {
            self::$instance = new self();
        }
        return self::$instance;
    }
    public function setLocaleConfig($country = null)
    {
        $localeInfoPath = WOO_ATOME_PLUGIN_PATH . 'i18n' . \DIRECTORY_SEPARATOR . 'locale-info.php';
        if (\file_exists($localeInfoPath)) {
            $localeInfos = (include $localeInfoPath);
            $this->logger->info('[load_current_locale_info]: localeInfoArr => ' . \json_encode($localeInfos));
        }
        if (!$country) {
            $country = $this->getOption('country');
        }
        $this->logger->info('[load_current_locale_info]:Current country => ' . $country);
        $this->localeConfig = $localeInfos[$country] ?? [];
        $this->logger->info('[get_current_locale_info]: currentLocaleInfo => ' . \json_encode($this->localeConfig));
    }
    public function getConfig($name, $default = null)
    {
        $result = $this->getOption($name);
        if (!\is_null($result) && $result !== '') {
            return $result;
        }
        return $this->getLocaleConfig($name, $default);
    }
    protected function syncConfigIfExpired($expireSeconds = Atome::REMOTE_CONFIG_EXPIRE_SECONDS)
    {
        $last_updated_time = $this->atomeSettingApi->get_option('last_updated_time');
        if (empty($last_updated_time) || \time() - $expireSeconds > $last_updated_time) {
            (new SyncConfig())->handle();
        }
    }
    public function getOption($name, $default = null)
    {
        $value = $this->atomeSettingApi->get_option($name, $default);
        if (!is_admin() && $name === 'language' && $value === '__') {
            $value = \substr(get_bloginfo('language'), 0, 2);
        }
        return $value;
    }
    public static function get($name, $default = null)
    {
        return self::instance()->getConfig($name, $default);
    }
    public static function option($name, $default = null)
    {
        return self::instance()->getOption($name, $default);
    }
    public function update($name, $value)
    {
        $this->atomeSettingApi->update_option($name, $value);
    }
    public function getLocaleConfig($key = null, $default = null)
    {
        if (\is_null($key)) {
            return $this->localeConfig;
        }
        $keys = \array_filter(\explode('.', $key));
        $values = $this->localeConfig;
        foreach ($keys as $k) {
            $values = $values[$k] ?? $default;
        }
        return $values;
    }
    /**
     * @return AtomeSettingApi
     */
    public function getAtomeSettingApi()
    {
        return $this->atomeSettingApi;
    }
}
