<?php

namespace _PhpScoperAtome\Atome\Config;

use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Services\Logger;
use _PhpScoperAtome\Atome\Services\Sentry;
use Exception;
/** @internal */
class RemoteConfig
{
    protected $country;
    protected $config = [];
    public function setCountry($country)
    {
        $this->country = \strtoupper($country);
        return $this;
    }
    public function handle()
    {
        $url = Atome::getApiBaseUrl() . 'variables/' . $this->country;
        try {
            $response = wp_remote_get($url, ['method' => 'GET']);
            if (is_wp_error($response)) {
                throw new Exception('get configs info from atome error, url: ' . $url, -1);
            }
            if (empty($response['body'])) {
                throw new Exception('get configs info from atome error: Empty body.', -1);
            }
            $body = \json_decode($response['body'], \true);
            if (!\is_array($body) || empty($body) || !isset($body['country'])) {
                throw new Exception('get configs info from atome error: ' . \var_export($body, \true), -1);
            }
            $localeInfo = Config::instance()->getLocaleConfig();
            $intFactor = isset($localeInfo['int_factor']) ? \intval($localeInfo['int_factor']) : 100;
            $this->config = ['minimum_spend' => $body['minSpend'] / $intFactor];
        } catch (\Throwable $e) {
            Logger::instance()->error('get configs info from atome exception: ' . wc_print_r($e, \true));
            Sentry::instance()->capture($e);
        }
        return $this;
    }
    public function get($key = null)
    {
        return $this->config[$key] ?? 0;
    }
    public function getMinimumSpend()
    {
        return $this->get('minimum_spend');
    }
}
