<?php

namespace _PhpScoperAtome\Atome\Config;

use _PhpScoperAtome\Atome\AtomeGateway;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Services\Logger;
use _PhpScoperAtome\Atome\Services\Sentry;
use Exception;
/** @internal */
class SyncConfig
{
    public function handle()
    {
        $configs = $this->getConfigsFromAtome();
        if ($configs) {
            foreach ($configs as $key => $value) {
                AtomeGateway::instance()->update_option($key, $value);
            }
            AtomeGateway::instance()->update_option('last_updated_time', \time());
        }
        return $configs;
    }
    protected function getConfigsFromAtome()
    {
        $url = Atome::getApiBaseUrl() . 'variables/' . \strtoupper(Config::option('country'));
        try {
            $response = wp_remote_get($url, ['method' => 'GET']);
            if (is_wp_error($response)) {
                throw new Exception('get configs info from atome error, url: ' . $url, -1);
            }
            if (empty($response['body'])) {
                throw new Exception('get configs info from atome error: Empty body.', -1);
            }
            $body = \json_decode($response['body'], \true);
            if (!\is_array($body) || empty($body) || !isset($body['country'])) {
                return [];
            }
            $localeInfo = Config::instance()->getLocaleConfig();
            $intFactor = isset($localeInfo['int_factor']) ? \intval($localeInfo['int_factor']) : 100;
            return ['minimum_spend' => \intval($body['minSpend'] / $intFactor)];
        } catch (\Throwable $e) {
            Logger::instance()->error('get configs info from atome exception: ' . wc_print_r($e, \true));
            Sentry::instance()->capture($e);
        }
        return [];
    }
    protected function getVoucherFromAtome()
    {
        return null;
    }
}
