<?php

namespace _PhpScoperAtome\Atome;

use _PhpScoperAtome\Atome\Enums\OrderStatus;
use _PhpScoperAtome\Atome\Payment\SubmitPayment;
use _PhpScoperAtome\Atome\Services\Logger;
use _PhpScoperAtome\Atome\Services\Sentry;
use WC_Order;
/** @internal */
trait CreateOrderBeforePayment
{
    public function process_payment($order_id)
    {
        Logger::instance()->info('atome_process_payment: order_id => ' . \json_encode($order_id));
        $order = wc_get_order($order_id);
        if (!$order instanceof WC_Order) {
            Logger::instance()->error('atome_process_payment valid order: false');
            return \false;
        }
        if ($order->get_status() !== OrderStatus::PENDING) {
            Logger::instance()->error('atome_process_payment wrong order status: ' . $order->get_status());
            return \false;
        }
        try {
            $submitPayment = new SubmitPayment();
            $submitPayment->setOrderId($order_id)->setOrderTotal($this->get_order_total())->handle();
            if ($submitPayment->isSuccess()) {
                return ['result' => 'success', 'redirect' => $submitPayment->getRedirectUrl()];
            } else {
                throw new \Exception('Process payment failed');
            }
        } catch (\Throwable $e) {
            $error_msg = $e->getMessage() . '(' . $e->getCode() . ')';
            Logger::instance()->error($error_msg . $e->getTraceAsString());
            wp_send_json(['result' => 'failure', 'messages' => '<div class="woocommerce-error">' . $error_msg . '</div>']);
            Sentry::instance()->capture($e);
            return \false;
        }
    }
}
