<?php

namespace _PhpScoperAtome\Atome;

use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Payment\Callback;
use _PhpScoperAtome\Atome\Payment\Result;
/** @internal */
class Hook
{
    public function boot()
    {
        /*
         * global hooks
         */
        add_filter('woocommerce_payment_gateways', [$this, 'woocommerce_payment_gateways']);
        add_action('wp_head', [new PriceDivider(), 'handle']);
        add_filter('http_request_timeout', [$this, 'http_request_timeout']);
        add_filter('wp_mail', [$this, 'wp_mail']);
        add_filter('plugin_action_links_' . Atome::PLUGIN_ENTRANCE, [$this, 'plugin_action_links']);
        add_filter('manage_edit-shop_order_columns', [$this, 'manage_edit_shop_order_columns'], 20);
        add_action('manage_shop_order_posts_custom_column', [$this, 'manage_shop_order_posts_custom_column'], 20, 2);
        add_action('upgrader_process_complete', [$this, 'upgrader_process_complete'], 10, 2);
        /*
         * gateway hooks
         */
        add_action('woocommerce_api_atome', [new Callback(), 'handle']);
        add_action('woocommerce_api_result', [new Result(), 'handle']);
        add_action('woocommerce_api_link', [AtomeGateway::instance(), 'link_handler']);
        add_action('woocommerce_api_query', [AtomeGateway::instance(), 'query_handler']);
        add_action('woocommerce_api_atome_error_report', [new PriceDivider(), 'errorReport']);
        add_action('woocommerce_update_options_payment_gateways_' . Atome::ID, [AtomeGateway::instance(), 'process_admin_options']);
        add_filter('woocommerce_available_payment_gateways', [AtomeGateway::instance(), 'availablePaymentGateways'], 10, 1);
        $this->plugins_loaded_callback();
    }
    public function plugin_action_links($links)
    {
        $settings_link = '<a href="' . admin_url('admin.php?page=wc-settings&tab=checkout&section=atome') . '">' . __('Settings') . '</a>';
        \array_unshift($links, $settings_link);
        return $links;
    }
    /**
     * Add Atome payment method
     * @param $gateways
     * @return mixed
     */
    public function woocommerce_payment_gateways($gateways)
    {
        $gateways[] = AtomeGateway::instance();
        return $gateways;
    }
    public function http_request_timeout()
    {
        return 30;
    }
    public function wp_mail($mail_info)
    {
        if (isset($mail_info['message'])) {
            $mail_info['message'] = \str_ireplace('{{atome.site.logo}}', '<td><img style="display: block; width: 100%; max-width: 100px; margin: 0 auto;" src="' . get_site_icon_url() . '" alt="' . get_bloginfo('name') . '" /></td>', $mail_info['message']);
            if (\stripos($mail_info['message'], '{{atome.admin.phone}}') !== \false) {
                $admin_args = ['role' => 'administrator', 'fields' => ['id']];
                $admin_phone = '';
                $admin_usr = get_users($admin_args);
                foreach ($admin_usr as $user) {
                    $admin_phone = get_user_meta($user->id, 'billing_phone', \true);
                    if (!empty($admin_phone)) {
                        break;
                    }
                }
                $mail_info['message'] = \str_ireplace('{{atome.admin.phone}}', $admin_phone, $mail_info['message']);
            }
        }
        return $mail_info;
    }
    public function manage_edit_shop_order_columns($columns)
    {
        $reordered_columns = [];
        foreach ($columns as $key => $column) {
            if ($key == 'order_number') {
                $reordered_columns['atome_order_number'] = 'E-commerce order number';
            }
            $reordered_columns[$key] = $column;
        }
        return $reordered_columns;
    }
    public function manage_shop_order_posts_custom_column($column, $post_id)
    {
        if ('atome_order_number' == $column) {
            if (get_post_meta($post_id, '_payment_method', \true) == 'atome') {
                echo $post_id;
            }
        }
    }
    /**
     * This method is triggered when the plugin is active
     * @return void
     */
    public function register_activation_hook()
    {
    }
    /**
     * This method is triggered when the plugin is upgrade success
     * @return void
     */
    public function upgrader_process_complete($upgrader_object, $options)
    {
    }
    public function plugins_loaded_callback()
    {
        $setting = new AtomeSettingApi();
        $this->v430DataCompatibility($setting);
    }
    /**
     * @param AtomeSettingApi $setting
     * @return void
     */
    protected function v430DataCompatibility($setting)
    {
        if ($setting->get_option('data_compatibility_v430')) {
            return;
        }
        if ($applyOn = $setting->get_option('price_divider_applied_on')) {
            if ($applyOn === 'all') {
                $detail = 'yes';
                $list = 'yes';
            } else {
                if ($applyOn === 'product') {
                    $detail = 'yes';
                    $list = 'no';
                } else {
                    if ($applyOn === 'list') {
                        $detail = 'no';
                        $list = 'yes';
                    } else {
                        $detail = 'no';
                        $list = 'no';
                    }
                }
            }
            $setting->update_option('price_divider_on_detail_page', $detail);
            $setting->update_option('price_divider_on_list_page', $list);
            $setting->update_option('price_divider_applied_on', '');
        } else {
            if (!$setting->get_option('price_divider_on_detail_page')) {
                $setting->update_option('price_divider_on_detail_page', 'yes');
            }
            if (!$setting->get_option('price_divider_on_list_page')) {
                $setting->update_option('price_divider_on_list_page', 'yes');
            }
        }
        if (\is_null($setting->get_option('min_spend'))) {
            $setting->update_option('min_spend', 0);
        }
        if (!$setting->get_option('cancel_timeout')) {
            $setting->update_option('cancel_timeout', Atome::DEFAULT_CANCEL_TIMEOUT);
        }
        $setting->update_option('data_compatibility_v430', 1);
    }
}
