<?php

namespace _PhpScoperAtome\Atome\Payment;

use _PhpScoperAtome\Atome\Config\Config;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Services\Logger;
use WP_Error;
/** @internal */
class Refund extends Payment
{
    use Integerize;
    protected $amount;
    protected $orderId;
    public function handle()
    {
        $requestBody = ['refundAmount' => $this->integerize($this->amount)];
        if (\in_array(Config::option('country'), ['tw', 'jp']) && $this->amount != $requestBody['refundAmount']) {
            return new WP_Error('atome', 'The refund amount must be integer.');
        }
        $response = wp_remote_post(Atome::getApiBaseUrl() . "payments/{$this->orderId}/refund", ['method' => 'POST', 'headers' => $this->getHeader(), 'body' => \json_encode($requestBody)]);
        Logger::instance()->info('Refund Response: ' . wc_print_r(['response' => $response['response']], \true));
        if (is_wp_error($response) || wp_remote_retrieve_response_code($response) !== 200) {
            Logger::instance()->error('Refund Response: ' . \json_encode($response));
            return $response;
        }
        if (empty($response['body'])) {
            return new WP_Error('atome-api', 'Empty Response');
        }
        $result = \json_decode($response['body'], \true);
        Logger::instance()->info('Refund Result: ' . wc_print_r($result, \true));
        if (isset($result['status']) && ($result['status'] == 'REFUNDED' || $result['status'] == 'PAID')) {
            return \true;
        }
        return new WP_Error('atome-api', 'error: ' . ($result['code'] ?? '') . ' | ' . ($result['message'] ?? ''));
    }
    /**
     * @param mixed $amount
     * @return Refund
     */
    public function setAmount($amount)
    {
        $this->amount = $amount;
        return $this;
    }
    /**
     * @param mixed $orderId
     * @return Refund
     */
    public function setOrderId($orderId)
    {
        $this->orderId = $orderId;
        return $this;
    }
}
