<?php

namespace _PhpScoperAtome\Atome\Payment;

use _PhpScoperAtome\Atome\Config\Config;
use _PhpScoperAtome\Atome\Config\Language;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Enums\PaymentStatus;
use _PhpScoperAtome\Atome\Exceptions\MaximumSpeedException;
use _PhpScoperAtome\Atome\Exceptions\MinimumSpeedException;
use _PhpScoperAtome\Atome\Exceptions\UnsupportedCurrencyException;
use _PhpScoperAtome\Atome\Services\Logger;
use _PhpScoperAtome\Atome\Services\Validator;
use Exception;
/** @internal */
class SubmitPayment extends Payment
{
    use Integerize;
    protected $orderId;
    protected $orderTotal;
    protected $amount;
    protected $redirectUrl;
    /**
     * @var Validator
     */
    protected $validator;
    public function __construct()
    {
        $this->validator = new Validator();
    }
    protected function validate()
    {
        if (!$this->validator->isSupportedCurrency()) {
            throw new UnsupportedCurrencyException();
        }
        if ($this->validator->isLowerThanMinimumSpend($this->amount)) {
            throw new MinimumSpeedException();
        }
        if ($this->validator->isGreaterThanMaxSpend($this->amount)) {
            throw new MaximumSpeedException();
        }
    }
    public function handle()
    {
        $this->validate();
        $apiUrl = Atome::getApiBaseUrl() . 'payments';
        $response = wp_remote_post($apiUrl, ['method' => 'POST', 'headers' => $this->getHeader(), 'body' => \json_encode($this->getPayload())]);
        Logger::instance()->info(__METHOD__ . ':' . \json_encode($response));
        if (is_wp_error($response) || wp_remote_retrieve_response_code($response) !== 200) {
            Logger::instance()->error('Payment Response: ' . \json_encode($response));
            if (empty($response['body'])) {
                throw new Exception('Request for payment failed. empty response', -1012);
            }
            $body = \json_decode($response['body'], \true);
            throw new Exception('Process payment failed, code:' . ($body['code'] ?? '') . ', message: ' . ($body['message'] ?? ''), -1013);
        }
        $body = \json_decode($response['body'], \true);
        if (isset($body['status']) && $body['status'] === PaymentStatus::PROCESSING) {
            $this->isSuccess = \true;
            $this->redirectUrl = $this->getRedirectURLByBrowser($body['redirectUrl'], $body['appPaymentUrl']);
            return;
        }
        throw new Exception('Process payment failed, code:' . ($body['code'] ?? '') . ', message: ' . ($body['message'] ?? ''), -1019);
    }
    protected function getRedirectURLByBrowser($redirectUrl, $appPaymentUrl)
    {
        $useragent = $_SERVER['HTTP_USER_AGENT'];
        $isMobile = \false;
        // @see http://detectmobilebrowsers.com/
        if (\preg_match('/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows ce|xda|xiino/i', $useragent) || \preg_match('/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\\-(n|u)|c55\\/|capi|ccwa|cdm\\-|cell|chtm|cldc|cmd\\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\\-s|devi|dica|dmob|do(c|p)o|ds(12|\\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\\-|_)|g1 u|g560|gene|gf\\-5|g\\-mo|go(\\.w|od)|gr(ad|un)|haie|hcit|hd\\-(m|p|t)|hei\\-|hi(pt|ta)|hp( i|ip)|hs\\-c|ht(c(\\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\\-(20|go|ma)|i230|iac( |\\-|\\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\\/)|klon|kpt |kwc\\-|kyo(c|k)|le(no|xi)|lg( g|\\/(k|l|u)|50|54|\\-[a-w])|libw|lynx|m1\\-w|m3ga|m50\\/|ma(te|ui|xo)|mc(01|21|ca)|m\\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\\-2|po(ck|rt|se)|prox|psio|pt\\-g|qa\\-a|qc(07|12|21|32|60|\\-[2-7]|i\\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\\-|oo|p\\-)|sdk\\/|se(c(\\-|0|1)|47|mc|nd|ri)|sgh\\-|shar|sie(\\-|m)|sk\\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\\-|v\\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\\-|tdg\\-|tel(i|m)|tim\\-|t\\-mo|to(pl|sh)|ts(70|m\\-|m3|m5)|tx\\-9|up(\\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\\-|your|zeto|zte\\-/i', \substr($useragent, 0, 4))) {
            $isMobile = \true;
        }
        return $isMobile ? $appPaymentUrl : $redirectUrl;
    }
    protected function getPayload()
    {
        $data = WC()->checkout()->get_posted_data();
        $cart = WC()->cart;
        $shipping_total = \unserialize(\base64_decode(get_post_meta($this->orderId, 'shipping_total', \true)));
        $cart_tax = \unserialize(\base64_decode(get_post_meta($this->orderId, 'cart_tax', \true)));
        $applied_coupons = $cart->get_applied_coupons();
        $payload = ['referenceId' => $this->orderId, 'currency' => get_woocommerce_currency(), 'amount' => $this->amount, 'expirationTime' => \intval(Config::instance()->getOption('cancel_timeout', Atome::DEFAULT_CANCEL_TIMEOUT)) * 60, 'callbackUrl' => get_site_url() . "/?wc-api=ATOME&referenceId={$this->orderId}", 'paymentResultUrl' => get_site_url() . '/?wc-api=RESULT&token=##paymentToken', 'paymentCancelUrl' => wc_get_checkout_url(), 'merchantReferenceId' => $this->orderId, 'customerInfo' => ['mobileNumber' => $data['billing_phone'], 'fullName' => $data['billing_last_name'] . ' ' . $data['billing_first_name'], 'email' => $data['billing_email']], 'shippingAddress' => ['countryCode' => $data['shipping_country'], 'lines' => [$data['shipping_city'], $data['shipping_address_1'], $data['shipping_address_2']], 'postCode' => $data['shipping_postcode']], 'billingAddress' => ['countryCode' => $data['billing_country'], 'lines' => [$data['billing_city'], $data['billing_address_1'], $data['billing_address_2']], 'postCode' => $data['billing_postcode']], 'taxAmount' => $this->integerize($cart_tax), 'shippingAmount' => $this->integerize($shipping_total), 'originalAmount' => $this->integerize($cart->get_subtotal()), 'voucherCode' => $applied_coupons[0] ?? '', 'items' => $this->getItems()];
        Logger::instance()->info(__METHOD__ . ':' . \json_encode($payload));
        return $payload;
    }
    protected function getItems()
    {
        $items = [];
        foreach (WC()->cart->get_cart() as $values) {
            $product = $values['data'];
            $items[] = ['name' => $product->get_name(), 'itemId' => $product->get_id(), 'quantity' => $values['quantity'], 'price' => $this->integerize($product->get_price()), 'variationName' => $product->get_name(), 'originalPrice' => $this->integerize($product->get_regular_price())];
        }
        return $items;
    }
    /**
     * @param mixed $orderId
     * @return SubmitPayment
     */
    public function setOrderId($orderId)
    {
        $this->orderId = $orderId;
        return $this;
    }
    /**
     * @param mixed $orderTotal
     * @return SubmitPayment
     * @throws Exception
     */
    public function setOrderTotal($orderTotal)
    {
        $this->orderTotal = $orderTotal;
        $this->amount = $this->integerize($this->orderTotal);
        if (\in_array(Config::option('country'), ['tw', 'jp']) && $this->amount != $this->orderTotal) {
            throw new Exception(Language::instance()->trans('The order total is not supported.'), -1015);
        }
        return $this;
    }
    /**
     * @return bool
     */
    public function isSuccess()
    {
        return $this->isSuccess;
    }
    /**
     * @return mixed
     */
    public function getRedirectUrl()
    {
        return $this->redirectUrl;
    }
}
