<?php

namespace _PhpScoperAtome\Atome;

use _PhpScoperAtome\Atome\Config\Config;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Services\LogRequest;
/** @internal */
class PriceDivider
{
    public function handle()
    {
        $country = Config::option('country');
        $language = Config::option('language');
        $isAtomeEnabled = \in_array(Atome::ID, \array_keys(WC()->payment_gateways->get_available_payment_gateways()));
        $applyOn = $this->appliedOn();
        $options = ['is_atome_enabled' => $isAtomeEnabled, 'country' => $country, 'language' => $language, 'api_environment' => Config::option('api_environment'), 'price_divider' => $this->isEnabled(), 'price_divider_applied_on' => $this->appliedOn(), 'sku_permission' => Config::option('sku_permission'), 'max_spend' => Config::option('max_spend'), 'min_spend' => Config::option('min_spend'), 'cancel_timeout' => Config::option('cancel_timeout'), 'debug_mode' => Config::option('debug_mode'), 'version' => Atome::version(), 'platform' => Atome::PLATFORM, 'enable_send_errors' => Config::option('enable_send_errors'), 'error_report_url' => get_site_url() . '/?wc-api=atome_error_report'];
        echo '<script type="text/javascript">window.atomePaymentPluginPriceDividerOptions = ' . \json_encode($options) . ';</script>';
        $isPriceDividerEnabled = $applyOn !== 'none';
        if ($isAtomeEnabled && $isPriceDividerEnabled) {
            echo '<script id="atome-price-divider-js" src="' . Atome::staticFileDomain() . '/price_divider/main.js" defer></script>';
        }
    }
    protected function isEnabled()
    {
        return $this->appliedOn() === 'none' ? 'no' : 'yes';
    }
    protected function appliedOn()
    {
        $detailPage = Config::instance()->getOption('price_divider_on_detail_page') === 'yes';
        $listPage = Config::instance()->getOption('price_divider_on_list_page') === 'yes';
        if ($detailPage && $listPage) {
            return 'all';
        }
        if ($detailPage) {
            return 'product';
        }
        if ($listPage) {
            return 'list';
        }
        return 'none';
    }
    public function errorReport()
    {
        $data = \json_decode(\file_get_contents("php://input"), \true);
        $type = $data['type'];
        $content = ['type' => $type, 'content' => $data['content'], 'configuration' => $data['configuration']];
        $detail = get_option('atome_price_divider_detail_error');
        $detailArr = \json_decode($detail ?: '{}', \true);
        if (!$type || isset($detailArr[$type])) {
            wp_send_json_success();
            return;
        }
        $detailArr[$type] = $content;
        update_option('atome_price_divider_detail_error', \json_encode($detailArr));
        wp_send_json_success();
    }
    public function boot()
    {
        global $pagenow;
        if (is_admin() && $pagenow === 'index.php') {
            (new LogRequest())->uploadPriceDividerError();
        }
    }
}
