<?php

namespace _PhpScoperAtome\Atome;

use _PhpScoperAtome\Atome\Config\Config;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Services\Logger;
use WP_REST_Request;
use WP_REST_Response;
/** @internal */
trait Query
{
    public function link_handler()
    {
        $result = ['code' => 200, "message" => "OK"];
        $check = $_GET['check'] ?? null;
        switch ($check) {
            case 'version':
                $result['version'] = Atome::version();
                break;
            case 'query':
                foreach ($this->form_fields as $key => $item) {
                    if (\in_array($key, ['api_key', 'password'])) {
                        continue;
                    }
                    $result[$key] = Config::option($key);
                }
                break;
            case 'plugins':
                if ($this->isAuthorizationMatched()) {
                    $result['plugins'] = get_plugins();
                    $result['active_plugins'] = get_option('active_plugins', []);
                }
                break;
            case 'update_settings':
                if ($this->isAuthorizationMatched()) {
                    $settingApi = Config::instance()->getAtomeSettingApi();
                    foreach ($_GET as $key => $value) {
                        if (\in_array($key, ['wc-api', 'check'])) {
                            continue;
                        }
                        $settingApi->update_option($key, $value);
                    }
                }
                break;
            default:
                break;
        }
        wp_send_json($result);
    }
    protected function isAuthorizationMatched()
    {
        $allHeaders = \getallheaders();
        $authorization = $allHeaders['Authorization'] ?? '';
        if (empty($authorization)) {
            $authorization = $_GET['Authorization'] ?? '';
        }
        return $this->validator->isAuthorized($authorization);
    }
    public function query_handler()
    {
        \ini_set('display_errors', 'Off');
        $allHeaders = \getallheaders();
        $authorization = $allHeaders['Authorization'] ?? '';
        if (empty($authorization)) {
            $authorization = $_GET['Authorization'] ?? null;
        }
        $this->validator->isAuthorized($authorization);
        add_filter('woocommerce_rest_check_permissions', function () {
            return Config::option('sku_permission') === 'yes';
        }, 10, 0);
        $queryUri = '/wc/v3';
        $type = 'products';
        $queryUri .= '/';
        $queryUri .= $type;
        $subType = $_GET['sub_type'] ?? '';
        if (!empty($subType)) {
            $queryUri .= '/';
            $queryUri .= $subType;
        }
        if (isset($_GET['product_id'])) {
            $queryUri = $queryUri . '/' . $_GET['product_id'];
        } else {
            if (isset($_GET['id'])) {
                $queryUri .= '/';
                $queryUri .= $_GET['id'];
            }
        }
        $request = new WP_REST_Request('GET', $queryUri);
        $request->set_query_params($_GET);
        $response = rest_do_request($request);
        if ($response instanceof WP_REST_Response) {
            if ('200' != $response->get_status()) {
                Logger::instance()->info('Query ' . $queryUri . ' response : ' . wc_print_r($response, \true));
                wp_send_json(['headers' => $response->get_headers(), 'status' => $response->get_status(), 'data' => $response->get_data(), 'links' => $response->get_links()]);
            }
            $rsp_data = $response->get_data();
            if (!\is_array($rsp_data)) {
                wp_send_json(['data' => wc_print_r($rsp_data, \true)]);
            }
            // products & price handling
            if ('' == $subType) {
                if (isset($rsp_data['id'])) {
                    $rsp_data['price'] = wc_format_decimal($this->get_price_to_display($rsp_data['id']), wc_get_price_decimals());
                    wp_send_json($rsp_data);
                }
                foreach ($rsp_data as &$product) {
                    if (!isset($product['id'])) {
                        continue;
                    }
                    $product['price'] = wc_format_decimal($this->get_price_to_display($product['id']), wc_get_price_decimals());
                }
            }
            wp_send_json($rsp_data);
        }
        Logger::instance()->info('Query ' . $queryUri . ' response : ' . wc_print_r($response, \true));
        wp_send_json(['error' => wc_print_r($response, \true)]);
    }
}
