<?php

namespace _PhpScoperAtome\Atome\Services;

use _PhpScoperAtome\Atome\Config\Config;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Enums\Environment;
/** @internal */
class LogRequest
{
    public function uninstall($reasonId, $reasonInfo)
    {
        $InformationLevel = "6";
        $fields = ['device' => $this->getDevice(1), 'logs' => [['level' => $InformationLevel, 'msg' => \json_encode(['type' => 'UNINSTALL', 'reason_id' => $reasonId, 'reason' => $reasonInfo, 'environment' => $this->getEnvironment()]), 'namespace' => $this->getDomain(), 'timestamp' => \date('Y/m/d H:i:s')]]];
        return $this->curlRequest($this->getUrl(), $fields);
    }
    public function uploadPriceDividerError()
    {
        $time = (int) get_option('atome_price_divider_detail_error_upload_time');
        if (\time() - $time < 1440) {
            return null;
        }
        $errors = get_option('atome_price_divider_detail_error') ?: "{}";
        $errors = \json_decode($errors, \true);
        if (!$errors || !\is_array($errors)) {
            return null;
        }
        $logs = [];
        $namespace = $this->getDomain();
        $timestamp = \date('Y/m/d H:i:s');
        $errorLevel = '3';
        foreach ($errors as $error) {
            $logs[] = ['level' => $errorLevel, 'namespace' => $namespace, 'timestamp' => $timestamp, 'msg' => \json_encode($error)];
        }
        $fields = ['device' => $this->getDevice(2), 'logs' => $logs];
        $this->curlRequest($this->getUrl(), $fields);
        update_option('atome_price_divider_detail_error_upload_time', \time(), \false);
        update_option('atome_price_divider_detail_error', "{}", \false);
    }
    protected function getDomain()
    {
        return \str_replace(array('http://', 'https://'), '', site_url());
    }
    protected function getDevice($osType)
    {
        return ["deviceId" => "EMPTY", "appVersion" => Atome::version(), "osType" => (string) $osType, "osVersion" => Atome::version(), "projectName" => "merchant_plugin"];
    }
    protected function getEnvironment()
    {
        global $wpdb;
        return ['software' => $_SERVER['SERVER_SOFTWARE'], 'php_version' => \phpversion(), 'mysql_version' => $wpdb->db_version(), 'wp_version' => get_bloginfo('version'), 'wc_version' => !\defined('WC_VERSION') ? '' : WC_VERSION, 'locale' => get_locale(), 'multisite' => is_multisite() ? 'Yes' : 'No'];
    }
    protected function getUrl()
    {
        $env = \strtolower(Config::option('api_environment'));
        return $env === Environment::STAGING ? Atome::STAGING_LOG_URL : Atome::PRODUCTION_LOG_URL;
    }
    protected function curlRequest($url, $fields)
    {
        $ch = \curl_init();
        \curl_setopt($ch, \CURLOPT_URL, $url);
        \curl_setopt($ch, \CURLOPT_POST, \true);
        \curl_setopt($ch, \CURLOPT_POSTFIELDS, \json_encode($fields));
        \curl_setopt($ch, \CURLOPT_HTTPHEADER, ['origin: https://sg-gateway.apaylater.net', 'Content-Type: application/json']);
        \curl_setopt($ch, \CURLOPT_RETURNTRANSFER, \true);
        return \curl_exec($ch);
    }
}
