<?php

namespace _PhpScoperAtome\Atome\Services;

use _PhpScoperAtome\Atome\Config\Config;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Enums\Environment;
use _PhpScoperAtome\Atome\Enums\LogLevel;
use WC_Log_Levels;
/** @internal */
class Logger
{
    /**
     * @var Logger
     */
    private static $instance = null;
    protected $logEnabledLevels = [];
    protected $logSessionId;
    public function __construct()
    {
        if (WC()->session && ($customerId = WC()->session->get_customer_unique_id())) {
            $this->logSessionId = $customerId;
        } else {
            $this->logSessionId = wp_generate_password(12, \false);
        }
    }
    public function boot()
    {
        if (Config::option('debug_mode') === 'yes' || Config::option('api_environment') === Environment::STAGING) {
            $levels = \array_values(LogLevel::toArray());
        } else {
            $levels = [];
            $errorNum = LogLevel::get_level_severity(WC_Log_Levels::ERROR);
            foreach (LogLevel::toArray() as $number => $name) {
                if ($number >= $errorNum) {
                    $levels[] = $name;
                }
            }
        }
        $this->logEnabledLevels = $levels;
    }
    public static function instance()
    {
        if (\is_null(self::$instance)) {
            self::$instance = new self();
        }
        return self::$instance;
    }
    public function log($message, $level = WC_Log_Levels::INFO, $context = [])
    {
        if (!$this->logEnabledLevels || !\in_array($level, $this->logEnabledLevels)) {
            return;
        }
        wc_get_logger()->log($level, "[{$this->logSessionId}] " . $message, \array_merge((array) $context, ['source' => Atome::ID]));
    }
    public function error($message, $context = [])
    {
        $this->log($message, WC_Log_Levels::ERROR, $context);
    }
    public function info($message, $context = [])
    {
        $this->log($message, WC_Log_Levels::INFO, $context);
    }
}
