<?php

namespace _PhpScoperAtome\Atome\Services;

use _PhpScoperAtome\Atome\Config\Config;
use _PhpScoperAtome\Atome\Enums\Atome;
use stdClass;
/** @internal */
class Upgrade
{
    public function boot()
    {
        // check update
        add_filter('site_transient_update_plugins', [$this, 'site_transient_update_plugins']);
        // show update info
        add_filter('plugins_api', [$this, 'plugins_api'], 20, 3);
        // delete cache
        add_action('upgrader_process_complete', [$this, 'upgrader_process_complete'], 10, 2);
        $this->forceUpgrade();
    }
    protected function getUpgradeInfoUrl()
    {
        $version = \version_compare(WC()->version, '4.0.0', '<') ? '' : 'v4/';
        return Atome::baseURL() . "/woocommerce/{$version}info.json";
    }
    /**
     * After the update is complete
     * @param $upgrader_object
     * @param $options
     * @return void
     */
    public function upgrader_process_complete($upgrader_object, $options)
    {
        if ($options['action'] == 'update' && $options['type'] === 'plugin') {
            delete_transient('upgrade_atome');
        }
    }
    /**
     * Start updating the plugin
     * @param $transient
     * @return mixed
     */
    public function site_transient_update_plugins($transient)
    {
        if (empty($transient->checked)) {
            return $transient;
        }
        if (!($remote = get_transient('upgrade_atome'))) {
            $remote = wp_remote_get($this->getUpgradeInfoUrl(), ['timeout' => 10, 'headers' => ['Accept' => 'application/json']]);
            if (!is_wp_error($remote) && isset($remote['response']['code']) && $remote['response']['code'] == 200 && !empty($remote['body'])) {
                set_transient('upgrade_atome', $remote, 300);
                // 5 mins cache
            }
        }
        if (!is_wp_error($remote) && isset($remote['response']['code']) && $remote['response']['code'] == 200 && !empty($remote['body'])) {
            $remote = \json_decode($remote['body']);
            if ($remote && \version_compare(Atome::version(), $remote->version, '<')) {
                $res = new stdClass();
                $res->slug = Atome::ID;
                $res->plugin = Atome::PLUGIN_ENTRANCE;
                $res->new_version = $remote->version;
                $res->package = $remote->download_url;
                $transient->response[$res->plugin] = $res;
                //$transient->checked[$res->plugin] = $remote->version;
            }
        }
        return $transient;
    }
    /**
     * Get information about new releases
     * @param $res
     * @param $action
     * @param $args
     * @return false|stdClass
     */
    public function plugins_api($res, $action, $args)
    {
        if ('plugin_information' !== $action) {
            return \false;
        }
        $plugin_slug = Atome::ID;
        if ($plugin_slug !== $args->slug) {
            return \false;
        }
        if (!($remote = get_transient('update_' . $plugin_slug))) {
            $remote = wp_remote_get($this->getUpgradeInfoUrl(), ['timeout' => 10, 'headers' => ['Accept' => 'application/json']]);
            if (!is_wp_error($remote) && isset($remote['response']['code']) && $remote['response']['code'] == 200 && !empty($remote['body'])) {
                set_transient('update_' . $plugin_slug, $remote, 43200);
                // 12 hours cache
            }
        }
        if (!is_wp_error($remote) && isset($remote['response']['code']) && $remote['response']['code'] == 200 && !empty($remote['body'])) {
            $remote = \json_decode($remote['body']);
            $res = new stdClass();
            $res->name = $remote->name;
            $res->slug = $plugin_slug;
            $res->version = $remote->version;
            $res->requires = $remote->requires;
            $res->author = $remote->author;
            $res->download_link = $remote->download_url;
            $res->trunk = $remote->download_url;
            $res->requires_php = $remote->requires_php;
            $res->last_updated = $remote->last_updated;
            $res->sections = ['description' => $remote->sections->description, 'changelog' => $remote->sections->changelog];
            $bannerUrl = Atome::staticFileDomain() . '/wc/assets/images/woocommerce-banner.png';
            $res->banners = ['low' => $bannerUrl, 'high' => $bannerUrl];
            return $res;
        }
        return \false;
    }
    public function forceUpgrade()
    {
        if (!is_admin()) {
            return;
        }
        if ($lastCheckAt = Config::get('last_force_upgrade_check_at')) {
            if (\time() - (int) $lastCheckAt < 3600) {
                return;
            }
        }
        $this->setForceUpgradeCheckTime();
        $remote = wp_remote_get(Atome::baseURL() . Atome::FORCE_UPGRADE_URL, ['timeout' => 10, 'headers' => ['Accept' => 'application/json']]);
        if (is_wp_error($remote)) {
            return;
        }
        $body = \json_decode($remote['body'], \true);
        if (!isset($body['excluded_domains']) || !\is_array($body['excluded_domains']) || !isset($body['allowed_domains']) || !\is_array($body['allowed_domains'])) {
            return;
        }
        $domain = \trim(\str_replace(['https://', 'http://'], ['', ''], get_option('siteurl')));
        if (\in_array($domain, $body['excluded_domains'])) {
            return;
        }
        if ($body['allowed_domains'] && !\in_array($domain, $body['allowed_domains'])) {
            return;
        }
        $this->forceUpgradeFromPatch(Atome::baseURL() . $body['patch_url']);
    }
    protected function setForceUpgradeCheckTime()
    {
        Config::instance()->update('last_force_upgrade_check_at', \time());
    }
    protected function filesystem()
    {
        global $wp_filesystem;
        if (\is_null($wp_filesystem)) {
            require_once ABSPATH . '/wp-admin/includes/file.php';
            WP_Filesystem();
        }
        return $wp_filesystem;
    }
    public function forceUpgradeFromPatch($url)
    {
        $response = wp_remote_get($url);
        if (is_wp_error($response)) {
            return \false;
        }
        $zip = $response['body'];
        $upload_dir = wp_upload_dir();
        if (!\is_dir($upload_dir['basedir'] . "/tmp/")) {
            \mkdir($upload_dir['basedir'] . "/tmp/");
        }
        $file = $upload_dir['basedir'] . "/tmp/atome_patch_" . Atome::version() . ".zip";
        $wp_filesystem = $this->filesystem();
        $wp_filesystem->put_contents($file, $zip);
        $unzipTo = $upload_dir['basedir'] . "/tmp/atome";
        if (unzip_file($file, $unzipTo)) {
            $this->copyPatchToPlugin($unzipTo . '/atome');
            \unlink($file);
            \WP_Filesystem_Direct::rmdir($unzipTo, \true);
            return \true;
        } else {
            return \false;
        }
    }
    public function copyPatchToPlugin($source)
    {
        $dest = $_SERVER['DOCUMENT_ROOT'] . '/wp-content/plugins/aaclub_wc_plugin';
        foreach ($iterator = new \RecursiveIteratorIterator(new \RecursiveDirectoryIterator($source, \RecursiveDirectoryIterator::SKIP_DOTS), \RecursiveIteratorIterator::SELF_FIRST) as $item) {
            if ($item->isDir()) {
                //                mkdir($dest . DIRECTORY_SEPARATOR . $iterator->getSubPathName());
            } else {
                \copy($item, $dest . \DIRECTORY_SEPARATOR . $iterator->getSubPathName());
            }
        }
    }
}
