<?php

namespace _PhpScoperAtome\Atome\Services;

use _PhpScoperAtome\Atome\Config\Config;
/** @internal */
class Validator
{
    public function isSupportedCurrency()
    {
        $wcCurrency = get_woocommerce_currency();
        $atomeCurrency = Config::instance()->getLocaleConfig('currency_code');
        Logger::instance()->info("isSupportedCurrency:{$wcCurrency} === {$atomeCurrency} result:" . ($wcCurrency && $wcCurrency === $atomeCurrency));
        return $wcCurrency && $wcCurrency === $atomeCurrency;
    }
    public function isAuthorized($authorizeToken, $unauthorizedResponse = \true)
    {
        try {
            $apiKey = Config::option('api_key');
            $password = Config::option('password');
            $localAuth = 'Basic' . \base64_encode("{$apiKey}:{$password}");
            $authorizeToken = \ucfirst($authorizeToken);
            if ($localAuth !== $authorizeToken) {
                if ($unauthorizedResponse) {
                    \header("HTTP/1.1 401 Unauthorized");
                    die(\json_encode(['code' => '401', 'message' => 'You are unauthorized to access']));
                }
                return \false;
            }
            return \true;
        } catch (\Throwable $e) {
            Logger::instance()->error($e->getMessage());
            Sentry::instance()->capture($e);
            if ($unauthorizedResponse) {
                \header("HTTP/1.1 401 Unauthorized");
                die(\json_encode(['code' => '401', 'message' => 'You are unauthorized to access']));
            }
            return \false;
        }
    }
    public function isLowerThanMinimumSpend($amount)
    {
        $minimumSpend = \intval(\intval(Config::get('minimum_spend', 10)) * \intval(Config::get('int_factor', 100)));
        return $amount < $minimumSpend;
    }
    public function isGreaterThanMaxSpend($amount)
    {
        $max_spend = \intval(Config::option('max_spend'));
        $int_factor = \intval(Config::get('int_factor', 100));
        $max_spend_amount = \intval(\intval($max_spend) * $int_factor);
        if (!empty($max_spend) && $max_spend_amount > 0 && $amount > $max_spend_amount) {
            return \true;
        }
        return \false;
    }
    public function inValidSpendAmountRange($spend)
    {
        if (!$spend) {
            return \true;
        }
        $minSpend = (int) Config::instance()->getOption('min_spend');
        $maxSpend = (int) Config::instance()->getOption('max_spend');
        Logger::instance()->info("inValidSpendAmountRange:minSpend:{$minSpend},maxSpend:{$maxSpend}, result:" . ($spend >= $minSpend && ($maxSpend == 0 || $spend <= $maxSpend)));
        return $spend >= $minSpend && ($maxSpend == 0 || $spend <= $maxSpend);
    }
}
