<?php

namespace _PhpScoperAtome\Atome;

use _PhpScoperAtome\Atome\Config\Config;
use _PhpScoperAtome\Atome\Config\RemoteConfig;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Enums\Environment;
use _PhpScoperAtome\Atome\Payment\Auth;
use _PhpScoperAtome\Atome\Services\Logger;
use WC_Admin_Settings;
/** @internal */
trait Setting
{
    public function process_admin_options()
    {
        if (!$this->validateWooCommerceVersion()) {
            return;
        }
        parent::process_admin_options();
        $this->trimKeyAndPassword();
        $this->updateMinSpend();
        $this->updateCancelTimeout();
        $this->validateApiKeyAndCallback();
    }
    protected function getSettingFormValue($key)
    {
        $formKey = "woocommerce_{$this->id}_{$key}";
        $postData = $this->get_post_data();
        return $postData[$formKey] ?? '';
    }
    protected function validateApiKeyAndCallback()
    {
        $auth = new Auth();
        $auth->setCountry($this->getSettingFormValue('country'))->setApiKey($this->getSettingFormValue('api_key'))->setPassword($this->getSettingFormValue('password'))->setConfiguration(['version' => Atome::version(), 'enabled' => \in_array(Atome::ID, \array_keys(WC()->payment_gateways->get_available_payment_gateways())), 'country' => $this->getSettingFormValue('country'), 'environment' => $this->getSettingFormValue('api_environment') === Environment::STAGING ? 'test' : 'production', 'language' => $this->getSettingFormValue('language'), 'skuPermission' => $this->getSettingFormValue('sku_permission') == '1' || $this->getSettingFormValue('sku_permission') === 'yes', 'priceDividerProductList' => $this->getSettingFormValue('price_divider_on_list_page') == '1' || $this->getSettingFormValue('price_divider_on_list_page') === 'yes', 'priceDividerProductDetail' => $this->getSettingFormValue('price_divider_on_detail_page') == '1' || $this->getSettingFormValue('price_divider_on_detail_page') === 'yes', 'minimumAmount' => (float) $this->getSettingFormValue('min_spend'), 'maximumAmount' => (float) $this->getSettingFormValue('max_spend'), 'cancelTimeout' => (int) $this->getSettingFormValue('cancel_timeout'), 'debugMode' => $this->getSettingFormValue('debug_mode') == '1' || $this->getSettingFormValue('debug_mode') === 'yes', 'enable_send_errors' => $this->getSettingFormValue('enable_send_errors') == '1' || $this->getSettingFormValue('enable_send_errors') == 'yes'])->handle();
        Logger::instance()->info('process_admin_options response: ' . \json_encode($auth->getResponse()));
        $body = $auth->getBody();
        if (!$auth->isHTTPSuccess() || !$auth->isCodeSuccess()) {
            $error = __('There was an error while verifying `Api Key` and `Api Password`, please try again later.', 'woocommerce');
            WC_Admin_Settings::add_error($error);
            if ($auth->isEmptyBody() || !isset($body['code'])) {
                return;
            }
            switch ($body['code']) {
                case 'UNAUTHORIZED':
                    $message = 'UNAUTHORIZED: Please check if `Api Key` and `Api Password` are wrong';
                    break;
                default:
                    $message = "{$body['code']}: " . $body['message'];
                    break;
            }
            WC_Admin_Settings::add_error($message);
        }
    }
    protected function validateWooCommerceVersion()
    {
        if (\version_compare(WC()->version, Atome::MINIMUM_WOOCOMERCE_VERSION, '<')) {
            WC_Admin_Settings::add_error('Sorry, current atome plugin does not support WooCommerce version below ' . Atome::MINIMUM_WOOCOMERCE_VERSION . '. To continue, kindly upgrade your WooCommerce version or download the old version here ( ' . Atome::LEGACY_VERSION_ZIP_URL . ' ).');
            return \false;
        }
        return \true;
    }
    protected function updateCancelTimeout()
    {
        $timeout = $this->getSettingFormValue('cancel_timeout');
        if ($timeout >= Atome::MINIMUM_CANCEL_TIMEOUT && $timeout <= Atome::MAXIMUM_CANCEL_TIMEOUT) {
            return;
        }
        $this->update_option('cancel_timeout', Atome::DEFAULT_CANCEL_TIMEOUT);
        if ($this->getSettingFormValue('cancel_timeout')) {
            WC_Admin_Settings::add_error('The input "Cancel Timeout" is not within the allowed range [' . Atome::MINIMUM_CANCEL_TIMEOUT . ' - ' . Atome::MAXIMUM_CANCEL_TIMEOUT . ']');
        }
    }
    protected function updateMinSpend()
    {
        $remoteConfig = new RemoteConfig();
        $remoteMinimumSpend = $remoteConfig->setCountry(Config::instance()->getOption('country'))->handle()->getMinimumSpend();
        $formMinimumSpend = $this->getSettingFormValue('min_spend');
        if ($formMinimumSpend >= $remoteMinimumSpend) {
            return;
        }
        $this->update_option('min_spend', $remoteMinimumSpend);
        if ($formMinimumSpend) {
            WC_Admin_Settings::add_error('The input "Minimum Amount" is below the minimum limit of ' . $remoteMinimumSpend);
        }
    }
    protected function trimKeyAndPassword()
    {
        $this->update_option('api_key', \trim($this->getSettingFormValue('api_key')));
        $this->update_option('password', \trim($this->getSettingFormValue('password')));
    }
    protected function stagingNotice()
    {
        if (Atome::baseURL() === Atome::PRODUCTION_BASE_URL) {
            return;
        }
        WC_Admin_Settings::add_error('Please download the production zip ( ' . Atome::PRODUCTION_VERSION_ZIP_URL . ' ) to enable all Atome services.');
    }
    /**
     * Atome options, we deal with it in Step 3 too
     */
    public function init_form_fields()
    {
        $this->stagingNotice();
        $this->form_fields = ['basic_settings' => ['title' => 'Basic settings', 'type' => 'title', 'description' => ''], 'country' => ['title' => 'Country/Region', 'type' => 'select', 'options' => ['sg' => 'Singapore', 'hk' => 'Hongkong', 'id' => 'Indonesia', 'jp' => 'Japan', 'tw' => 'Taiwan', 'th' => 'Thailand', 'my' => 'Malaysia', 'ph' => 'Philippines', 'vn' => 'Vietnam'], 'default' => 'sg'], 'language' => ['title' => 'Language', 'type' => 'select', 'options' => ['__' => 'Flexible (recommend)', 'en' => 'English', 'zh' => '繁體中文', 'id' => 'bahasa Indonesia', 'vi' => 'Tiếng Việt', 'th' => 'ภาษาไทย', 'ja' => '日本語', 'ms' => 'Melayu'], 'default' => '__', 'description' => 'Flexible means any of the languages supported by Atome can be chosen by customers during the checkout flow', 'desc_tip' => \true], 'api_environment' => ['title' => 'Environment', 'type' => 'select', 'options' => [Environment::PRODUCTION => 'Production', Environment::STAGING => 'Test'], 'description' => "The test environment is on for testing purposes. Please enable the production to process real transactions.", 'default' => Environment::PRODUCTION], 'api_key' => ['title' => 'API Key', 'type' => 'text', 'description' => 'For access auth to atome payment gateway', 'desc_tip' => \true], 'password' => ['title' => 'API Password', 'type' => 'password', 'description' => 'For access auth to atome payment gateway', 'desc_tip' => \true], 'sku_permission' => ['title' => 'SKU Permission', 'type' => 'checkbox', 'label' => 'Allow Atome to display SKU information in our APP to increase exposure', 'default' => 'yes'], 'price_divider_settings' => ['title' => 'Price Divider Settings', 'type' => 'title'], 'price_divider_on_detail_page' => ['title' => 'Price Divider (Product Detail)', 'type' => 'checkbox', 'label' => '', 'default' => 'yes'], 'price_divider_on_list_page' => ['title' => 'Price Divider (Product List)', 'type' => 'checkbox', 'label' => '', 'default' => 'yes'], 'advanced_settings' => ['title' => 'Advanced Settings', 'type' => 'title', 'description' => ''], 'max_spend' => ['title' => 'Maximum Amount', 'type' => 'number', 'description' => 'Order will not be placed when order total is over than maximum amount. Price divider will not be shown when product price is over than maximum amount.', 'placeholder' => '0 or empty for no limit', 'desc_tip' => \true, 'default' => 0], 'min_spend' => ['title' => 'Minimum Amount', 'type' => 'text', 'description' => 'Order will not be placed when order total is less than minimum amount. Price divider will not be shown when product price is less than minimum amount.', 'placeholder' => '0 or empty for no limit', 'desc_tip' => \true, 'default' => 0], 'cancel_timeout' => ['title' => 'Cancel Timeout(min)', 'type' => 'number', 'default' => Atome::DEFAULT_CANCEL_TIMEOUT, 'description' => 'Support flexible setting between 10 min to 720 min. By default, the order will be canceled in 12 hours if without payment.'], 'debug_mode' => ['title' => 'Debug Mode', 'label' => 'Debug Mode', 'type' => 'checkbox', 'default' => 'yes', 'description' => 'More detailed logs will be recorded when checked', 'desc_tip' => \true], 'enable_send_errors' => ['title' => 'Anonymously Report Errors', 'label' => 'Anonymously Report Errors', 'type' => 'checkbox', 'default' => 'no', 'description' => 'Anonymously send non-private program exception data to Atome', 'desc_tip' => \true]];
    }
}
