<?php

namespace _PhpScoperAtome\Atome;

use _PhpScoperAtome\Atome\Config\Config;
use _PhpScoperAtome\Atome\Config\Language;
use _PhpScoperAtome\Atome\Enums\Atome;
use _PhpScoperAtome\Atome\Services\Logger;
use _PhpScoperAtome\Atome\Services\Sentry;
use WC_Product;
/** @internal */
trait View
{
    public function get_title()
    {
        if (is_admin() || wp_is_mobile() || \preg_match('/sammrepublic.com/', get_option('siteurl'))) {
            return 'Atome';
        }
        $localeInfo = Config::instance()->getLocaleConfig();
        $title = \preg_replace_callback('/{{(\\w+?)}}/', function ($matches) use($localeInfo) {
            if ('atome_logo' == $matches[1]) {
                if (is_checkout() && get_query_var('wc-ajax') === 'update_order_review') {
                    if (\preg_match('/otobodycare.com/', get_option('siteurl'))) {
                        return '';
                    } elseif (\preg_match('/studiofivepixels\\.com/', get_option('siteurl'))) {
                        return '<img class="atome-icon" src="' . Atome::staticFileDomain() . '/common/assets/svg/logo-pd-dark.svg" alt="Atome" style="display: inline-block;vertical-align:text-bottom;float:none;width: initial;margin-left: initial;">';
                    } else {
                        return '<img class="atome-icon" src="' . Atome::staticFileDomain() . '/common/assets/svg/logo-pd.svg" alt="Atome" style="display: inline-block;vertical-align:text-bottom;float:none;width: initial;margin-left: initial;">';
                    }
                } else {
                    return 'Atome';
                }
            }
            return $localeInfo[$matches[1]] ?? '';
        }, Language::instance()->get('title'));
        return $title;
    }
    public function getPlainDescription()
    {
        return Language::instance()->get('plain_description');
    }
    public function get_description()
    {
        $localeInfo = Config::instance()->getLocaleConfig();
        $language = Config::option('language');
        $minimum_spend = Config::get('minimum_spend');
        return \preg_replace_callback('/{{(\\w+?)}}/', function ($matches) use($localeInfo, $language, $minimum_spend) {
            if ('currency_name' == $matches[1]) {
                return $localeInfo['currency_name'][$language] ?? 'Singapore Dollar';
            } else {
                if ('minimum_spend' == $matches[1]) {
                    return wc_price($minimum_spend);
                }
            }
            return $localeInfo[$matches[1]] ?? '';
        }, Language::instance()->get('description'));
    }
    public function get_icon()
    {
        $localeInfo = Config::instance()->getLocaleConfig();
        $result = '';
        if (!empty($localeInfo['checkout_logo'])) {
            $checkout_icon_url = Atome::staticFileDomain() . '/common/assets/svg/' . $localeInfo['checkout_logo'];
            $result = '<img src=' . $checkout_icon_url . ' style="height:24px;display: inline-flex;vertical-align: middle;margin-left: 6px;width: initial;"/>' . $result;
        }
        return $result;
    }
    public function get_price_to_display($product)
    {
        global $flycart_woo_discount_rules, $awdr_load_version;
        if (!$product instanceof WC_Product) {
            $product = wc_get_product($product);
        }
        $price_to_display = \false;
        if ($awdr_load_version == "v2") {
            $custom_price = 0;
            if (\method_exists($product, 'is_type') && $product->is_type('variable') && \_PhpScoperAtome\Wdr\App\Controllers\DiscountCalculator::$config->getConfig('calculate_discount_from', 'sale_price')) {
                $custom_price = $product->get_variation_regular_price('min');
            }
            //not matched, apply_filters return false
            $price_to_display = apply_filters('advanced_woo_discount_rules_get_product_discount_price_from_custom_price', $price_to_display, $product, 1, $custom_price, 'discounted_price', \false, \false);
        } else {
            if (isset($flycart_woo_discount_rules)) {
                try {
                    $product_id = $product->get_id();
                    if (isset($flycart_woo_discount_rules->pricingRules->products_has_discount[$product_id]) && $flycart_woo_discount_rules->pricingRules->products_has_discount[$product_id] == 1) {
                        $price_to_display = $flycart_woo_discount_rules->pricingRules->getDiscountPriceForTheProduct($product);
                    }
                } catch (\Throwable $e) {
                    Logger::instance()->error('Get Price From flycart_woo_discount_rules Exception: ' . wc_print_r($e, \true));
                    Sentry::instance()->capture($e);
                }
            }
        }
        if ($price_to_display === \false) {
            $price_to_display = wc_get_price_to_display($product);
        }
        return $price_to_display;
    }
}
